@@ -35,19 +35,15 @@
 #include <klocalizedstring.h>
 #include <kcharsets.h>
 #include <qdebug.h>
+#include <QCoreApplication>
 
-#include <QtCore/QVector>
-#include <QtCore/QString>
-#include <QtCore/QTextCodec>
+#include <QVector>
+#include <QString>
+#include <QTextCodec>
 
 #include <ctype.h>
 #include <time.h>
 #include <stdlib.h>
-#ifdef WIN32
-#include <process.h>
-#else
-#include <unistd.h>
-#endif
 
 using namespace KMime;
 
@@ -164,12 +160,7 @@ QByteArray uniqueString()
     p[10] = '\0';
     now = time(nullptr);
     ran = 1 + (int)(1000.0 * rand() / (RAND_MAX + 1.0));
-    timeval = (now / ran)
-        #ifdef WIN32
-            + _getpid();
-        #else
-            + getpid();
-        #endif
+    timeval = (now / ran) + QCoreApplication::applicationPid();
 
     for (int i = 0; i < 10; i++) {
         pos = (int)(61.0 * rand() / (RAND_MAX + 1.0));
@@ -372,7 +363,7 @@ QByteArray extractHeader(const QByteArray &src, const QByteArray &name)
 
 QByteArray CRLFtoLF(const QByteArray &s)
 {
-    if (s.indexOf("\r\n") == -1) {
+    if (!s.contains("\r\n")) {
         return s;
     }
 
@@ -389,7 +380,7 @@ QByteArray CRLFtoLF(const char *s)
 
 QByteArray LFtoCRLF(const QByteArray &s)
 {
-    if (s.indexOf("\r\n") > -1) {
+    if (s.contains("\r\n")) {
         return s;
     }
 
